@@ -43,7 +43,7 @@ QNetworkReply* Dailymotion::createReply(QString feed, int offset) {
     url.addQueryItem("family_filter", safeSearch() ? "true" : "false");
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
 
     return networkAccessManager()->get(request);
 }
@@ -84,7 +84,7 @@ QNetworkReply* Dailymotion::createSearchReply(Queries::QueryType queryType, cons
     }
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
 
     return networkAccessManager()->get(request);
 }
@@ -138,7 +138,7 @@ void Dailymotion::signIn(const QString &displayName, const QUrl &response) {
                         "&redirect_uri=https://sites.google.com/site/marxodian/home/cutetube&grant_type=authorization_code");
 
         QNetworkRequest request(url);
-        request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+        request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
         request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
         QNetworkReply *reply = networkAccessManager()->post(request, body);
         connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedIn()));
@@ -158,7 +158,7 @@ void Dailymotion::signIn(const QString &displayName, const QString &user, const
                     "&redirect_uri=https://sites.google.com/site/marxodian/home/cutetube&grant_type=password");
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = networkAccessManager()->post(request, body);
     connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedIn()));
@@ -204,7 +204,7 @@ void Dailymotion::refreshAccessToken() {
                     "&grant_type=refresh_token");
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = networkAccessManager()->post(request, body);
     connect(reply, SIGNAL(finished()), this, SLOT(checkTokenRefresh()));
@@ -258,7 +258,7 @@ void Dailymotion::signOut() {
     emit busy(tr("Signing out..."));
     QUrl url("https://api.dailymotion.com/logout");
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", "OAuth " + accessToken().toUtf8());
     QNetworkReply* reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedOut()));
@@ -288,7 +288,7 @@ void Dailymotion::checkIfSignedOut() {
 
 void Dailymotion::postRequest(const QUrl &url, const QByteArray &data) {
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     request.setRawHeader("Authorization", "OAuth " + accessToken().toUtf8());
     QNetworkReply* reply = networkAccessManager()->post(request, data);
@@ -297,7 +297,7 @@ void Dailymotion::postRequest(const QUrl &url, const QByteArray &data) {
 
 void Dailymotion::deleteRequest(const QUrl &url) {
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", "OAuth " + accessToken().toUtf8());
     QNetworkReply* reply = networkAccessManager()->deleteResource(request);
     connect(reply, SIGNAL(finished()), this, SLOT(postFinished()));
@@ -358,7 +358,7 @@ void Dailymotion::getPlaylists(int offset) {
     url.addQueryItem("fields", DAILYMOTION_PLAYLIST_FIELDS);
     url.addQueryItem("access_token", accessToken());
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(addPlaylists()));
 }
@@ -456,7 +456,7 @@ void Dailymotion::getGroups(int offset) {
     url.addQueryItem("fields", DAILYMOTION_GROUP_FIELDS);
     url.addQueryItem("access_token", accessToken());
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(addGroups()));
 }
@@ -545,12 +545,7 @@ void Dailymotion::memberOfGroup(QSharedPointer<GroupItem> group) {
             i++;
         }
 
-        if (member) {
-            m_groupAction.data()->setMember(true);
-        }
-        else {
-            m_groupAction.data()->setMember(false);
-        }
+        m_groupAction.data()->setMember(member);
 
         disconnect(this, SIGNAL(allGroupsLoaded()), this, SLOT(memberOfGroup()));
     }
@@ -567,7 +562,7 @@ void Dailymotion::getSubscriptions(int offset) {
     url.addQueryItem("fields", DAILYMOTION_USER_FIELDS);
     url.addQueryItem("access_token", accessToken());
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(addSubscriptions()));
 }
@@ -663,9 +658,7 @@ void Dailymotion::subscribedToChannel(QSharedPointer<UserItem> user) {
         i++;
     }
 
-    if (subscribed) {
-        m_userAction.data()->setSubscribed(true);
-    }
+    m_userAction.data()->setSubscribed(subscribed);
 
     disconnect(this, 0, this, SLOT(subscribedToChannel()));
 }
@@ -682,7 +675,7 @@ void Dailymotion::getFullVideo(QString id) {
     url.addQueryItem("fields", DAILYMOTION_VIDEO_FIELDS);
     url.addQueryItem("family_filter", "false");
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(checkFullVideo()));
 }
@@ -725,7 +718,7 @@ void Dailymotion::getVideoMetadata(const QString &id) {
     url.addQueryItem("fields", DAILYMOTION_VIDEO_METADATA_FIELDS);
     url.addQueryItem("access_token", accessToken());
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(checkVideoMetadata()));
 }
@@ -777,7 +770,7 @@ void Dailymotion::getCurrentUserProfile() {
     url.addQueryItem("fields", DAILYMOTION_USER_PROFILE_FIELDS);
     url.addQueryItem("access_token", accessToken());
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(checkCurrentUserProfile()));
 }
@@ -836,7 +829,7 @@ void Dailymotion::getUserProfile(const QString &id) {
     QUrl url("https://api.dailymotion.com/user/" + id);
     url.addQueryItem("fields", DAILYMOTION_USER_PROFILE_FIELDS);
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(checkUserProfile()));
 }
@@ -1223,7 +1216,7 @@ void Dailymotion::getPlaylistForCache(const QString &id) {
     QUrl url("https://api.dailymotion.com/playlist/" + id);
     url.addQueryItem("fields", DAILYMOTION_PLAYLIST_FIELDS);
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(checkCachePlaylist()));
 }
@@ -1369,7 +1362,7 @@ void Dailymotion::getAddedComment(const QString &id) {
     QUrl url("https://api.dailymotion.com/comment/" + id);
     url.addQueryItem("fields", DAILYMOTION_COMMENT_FIELDS);
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(checkAddedComment()));
 }
@@ -1490,7 +1483,7 @@ void Dailymotion::getVideosFromIds(QStringList ids) {
     url.addQueryItem("limit", "100");
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(checkFullVideos()));
 }
