@@ -109,7 +109,7 @@ void DailymotionRelatedVideosTab::queueVideos() {
 }
 
 void DailymotionRelatedVideosTab::showContextMenu(const QPoint &pos) {
-    m_contextMenu->popup(pos, m_addToFavouritesAction);
+    m_contextMenu->popup(pos, m_addToFavouritesContextAction);
 }
 
 void DailymotionRelatedVideosTab::addVideoToFavourites() {
