@@ -134,7 +134,7 @@ void DailymotionVideoListTab::queueVideos() {
 }
 
 void DailymotionVideoListTab::showContextMenu(const QPoint &pos) {
-    m_contextMenu->popup(pos, m_deleteFromUploadsAction);
+    m_contextMenu->popup(pos, m_deleteFromUploadsContextAction);
 }
 
 void DailymotionVideoListTab::deleteVideoFromUploads() {
