@@ -31,6 +31,16 @@ private slots:
     void addVideoDownloads();
     void addAudioDownloads();
     void queueVideos();
+    void showContextMenu(const QPoint &pos);
+    void deleteVideoFromUploads();
+    void addVideoToFavourites();
+    void deleteVideoFromFavourites();
+    void showPlaylistDialog();
+    void addVideoToPlaylist(const QString &id);
+    void addVideoToNewPlaylist(const NewPlaylist &playlist);
+    void addVideoDownload();
+    void addAudioDownload();
+    void queueVideo();
     void onItemClicked(const QModelIndex &index);
     void showVideoInfo(QSharedPointer<VideoItem> video);
     void playVideo(const QModelIndex &index);
@@ -46,6 +56,14 @@ private:
     QAction *m_addToQueueAction;
     QAction *m_videoDownloadAction;
     QAction *m_audioDownloadAction;
+    QMenu *m_contextMenu;
+    QAction *m_deleteFromUploadsContextAction;
+    QAction *m_addToFavouritesContextAction;
+    QAction *m_deleteFromFavouritesContextAction;
+    QAction *m_addToPlaylistContextAction;
+    QAction *m_addToQueueContextAction;
+    QAction *m_videoDownloadContextAction;
+    QAction *m_audioDownloadContextAction;
     QLabel *m_noResultsLabel;
     QGridLayout *m_grid;
 };
