@@ -154,7 +154,7 @@ void DailymotionVideoListWindow::queueVideos() {
 }
 
 void DailymotionVideoListWindow::showContextMenu(const QPoint &pos) {
-    m_contextMenu->popup(pos, m_deleteFromUploadsAction);
+    m_contextMenu->popup(pos, m_deleteFromUploadsContextAction);
 }
 
 void DailymotionVideoListWindow::deleteVideoFromUploads() {
