@@ -1,4 +1,5 @@
 #include "homewindow.h"
+#include "utils.h"
 #include <QtGui>
 #include <QSettings>
 #include <QTranslator>
@@ -7,7 +8,7 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     app.setApplicationName("cuteTube");
-    app.setApplicationVersion("1.3.1");
+    app.setApplicationVersion(Utils::versionNumberString());
 
     QSettings settings("Marxian", "cuteTube");
     settings.beginGroup("System");
