@@ -24,6 +24,10 @@ private slots:
     void removeVideos();
     void addVideoDownloads();
     void addAudioDownloads();
+    void showContextMenu(const QPoint &pos);
+    void removeVideo();
+    void addVideoDownload();
+    void addAudioDownload();
     void onItemClicked(const QModelIndex &index);
     void playVideo(const QModelIndex &index);
     
@@ -32,6 +36,10 @@ private:
     QAction *m_removeAction;
     QAction *m_videoDownloadAction;
     QAction *m_audioDownloadAction;
+    QMenu *m_contextMenu;
+    QAction *m_removeContextAction;
+    QAction *m_videoDownloadContextAction;
+    QAction *m_audioDownloadContextAction;
     QLabel *m_noResultsLabel;
 };
 
