@@ -81,7 +81,7 @@ void Sharing::getTwitterAuthUrl() {
     QMap<QString, QString> params;
     params.insert("oauth_callback", m_redirectUri);
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", getTwitterOAuthHeader("GET", url.toString(), params));
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(checkTwitterAuthUrl()));
@@ -127,7 +127,7 @@ void Sharing::signInToTwitter(const QUrl &response) {
         params.insert("oauth_token_secret", twitterRequestSecret());
         params.insert("oauth_verifier", verifier);
         QNetworkRequest request(url);
-        request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+        request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
         request.setRawHeader("Authorization", getTwitterOAuthHeader("GET", url.toString(), params));
         QNetworkReply *reply = networkAccessManager()->get(request);
         connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedInToTwitter()));
@@ -197,7 +197,7 @@ void Sharing::postToFacebook(const VideoShare &post) {
             + "&description=" + m_post.description().toUtf8();
 
     QNetworkRequest request(QUrl("https://graph.facebook.com/me/feed"));
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = networkAccessManager()->post(request, postData);
     connect(reply, SIGNAL(finished()), this, SLOT(facebookPostFinished()));
@@ -244,7 +244,7 @@ void Sharing::postToTwitter(const VideoShare &post) {
     QMap<QString, QString> params;
     params.insert("status", QString(body));
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     request.setRawHeader("Authorization", getTwitterOAuthHeader("POST", url.toString(), params));
     QNetworkReply *reply = networkAccessManager()->post(request, "status=" + body);
@@ -320,7 +320,7 @@ void Sharing::getVideosFromFacebook() {
     url.addQueryItem("limit", "100");
     url.addQueryItem("access_token", facebookToken());
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(checkFacebookVideos()));
 }
@@ -418,7 +418,7 @@ void Sharing::getVideosFromTwitter() {
     }
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", getTwitterOAuthHeader("GET", "http://api.twitter.com/1/statuses/home_timeline.json", params));
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(checkTwitterVideos()));
