@@ -23,6 +23,10 @@ private slots:
     void addVideoDownloads();
     void addAudioDownloads();
     void queueVideos();
+    void showContextMenu(const QPoint &pos);
+    void addVideoDownload();
+    void addAudioDownload();
+    void queueVideo();
     void onItemClicked(const QModelIndex &index);
     void playVideo(const QModelIndex &index);
     void showVideoInfo(QSharedPointer<VideoItem> video);
@@ -34,6 +38,10 @@ private:
     QAction *m_addToQueueAction;
     QAction *m_videoDownloadAction;
     QAction *m_audioDownloadAction;
+    QMenu *m_contextMenu;
+    QAction *m_addToQueueContextAction;
+    QAction *m_videoDownloadContextAction;
+    QAction *m_audioDownloadContextAction;
     QLabel *m_noResultsLabel;
 };
 
