@@ -79,7 +79,7 @@ void TransferWorker::performDownload(const QString &videoUrl) {
 
     QUrl url(videoUrl);
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
 
     if (m_downloadFile.size() > 0) {
         request.setRawHeader("Range", "bytes=" + QByteArray::number(m_downloadFile.size()) + "-"); // Set 'Range' header if resuming a download
@@ -95,7 +95,7 @@ void TransferWorker::performDownload(const QString &videoUrl) {
 void TransferWorker::downloadThumbnail(const QString &fileName) {
     m_thumbFile.setFileName(m_path + ".thumbnails/" + fileName);
     QNetworkRequest request(m_transfer.data()->thumbnailUrl());
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(thumbnailDownloadFinished()));
 }
@@ -273,7 +273,7 @@ void TransferWorker::uploadVideo(QSharedPointer<TransferItem> transfer) {
     }
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Host", "uploads.gdata.youtube.com");
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/atom+xml; charset=UTF-8");
     request.setHeader(QNetworkRequest::ContentLengthHeader, xml.length());
@@ -322,7 +322,7 @@ void TransferWorker::performUpload(const QUrl &url) {
     }
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Nokia; Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Host", "uploads.gdata.youtube.com");
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/octet-stream");
     request.setHeader(QNetworkRequest::ContentLengthHeader, m_uploadFile.size());
