@@ -56,7 +56,6 @@ void UrlGrabber::getYouTubeVideoUrl(const QString &id) {
     emit busy(tr("Loading video"));
     QUrl url("http://www.youtube.com/get_video_info?&video_id=" + id + "&el=detailpage&ps=default&eurl=&gl=US&hl=en");
     QNetworkRequest request;
-    request.setRawHeader("User-Agent", "cuteTube/1.3.1 (Nokia; Qt)");
     request.setUrl(url);
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(parseYouTubeVideoPage()));
@@ -77,26 +76,23 @@ void UrlGrabber::parseYouTubeVideoPage() {
     QMap<int, QString> formats;
     QString response(QByteArray::fromPercentEncoding(reply->readAll()));
 
-    if (!response.contains("fmt_stream_map=url=")) {
+    if (!response.contains("url_encoded_fmt_stream_map=")) {
         emit error(tr("Unable to retrieve video. Access may be restricted"));
         return;
     }
 
-    response = response.split("fmt_stream_map=url=").at(1);
-    QStringList parts = response.split(QRegExp(",url=|&url="));
+    response = response.section("url_encoded_fmt_stream_map=", 1, 1);
+    QStringList parts = response.split("itag=", QString::SkipEmptyParts);
     QString part;
-    QStringList keySplit;
     QString url;
     int key;
 
     for (int i = 0; i < parts.length(); i++) {
         part = parts[i];
-        url = QByteArray::fromPercentEncoding(part.left(part.indexOf("c.youtube.com&") + 13).toAscii()).replace("%2C", ",");
-        keySplit = part.split("&itag=");
-        if (keySplit.size() > 1) {
-            key = keySplit.at(1).split(QRegExp("[&,]")).first().toInt();
-            formats[key] = url;
-        }
+        key = part.left(part.indexOf('&')).toInt();
+        url = part.section("url=", 1, -1);
+        url = QByteArray::fromPercentEncoding(url.section("&quality", 0, 0).toUtf8()).replace("%2C", ",").replace("sig=", "signature=");
+        formats[key] = url;
     }
 
     QString videoUrl;
@@ -127,7 +123,6 @@ void UrlGrabber::getDailymotionVideoUrl(const QString &id) {
     emit busy(tr("Loading video"));
     QUrl url("http://www.dailymotion.com/video/" + id);
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1");
     QNetworkReply *reply;
 
     if (m_mode == UrlGrabber::PlaybackMode) {
@@ -185,7 +180,6 @@ void UrlGrabber::parseDailymotionVideoPage() {
 
 void UrlGrabber::getDailymotionRedirect(const QUrl &url) {
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1");
     QNetworkReply *reply;
 
     if (m_mode == UrlGrabber::PlaybackMode) {
@@ -222,7 +216,6 @@ void UrlGrabber::getVimeoVideoUrl(const QString &id) {
     emit busy(tr("Loading video"));
     QUrl url("http://vimeo.com/" + id);
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1");
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(parseVimeoVideoPage()));
 
@@ -296,7 +289,6 @@ void UrlGrabber::parseVimeoVideoPage() {
 
 void UrlGrabber::getVimeoRedirect(const QUrl &url) {
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1");
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(checkVimeoRedirect()));
 }
@@ -312,7 +304,7 @@ void UrlGrabber::checkVimeoRedirect() {
     QString redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
 
     if (redirect.isEmpty()) {
-        emit error(tr("Unable to retrieve video. Access may be restricted"));
+        emit error(tr("Unable to retrieve video. Note that some videos are not available in 'Mobile' quality"));
     }
     else {
         emit gotVideoUrl(redirect);
@@ -325,7 +317,6 @@ void UrlGrabber::getXHamsterVideoUrl(const QString &url) {
     emit busy(tr("Loading video"));
     QNetworkRequest request;
     request.setUrl(QUrl(url));
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1");
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(parseXHamsterVideoPage()));
 
@@ -366,7 +357,6 @@ void UrlGrabber::getXVideosVideoUrl(const QString &url) {
     emit busy(tr("Loading video"));
     QNetworkRequest request;
     request.setUrl(QUrl(url));
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1");
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(parseXVideosVideoPage()));
 
@@ -401,7 +391,6 @@ void UrlGrabber::getJoggsVideoUrl(const QString &url) {
     emit busy(tr("Loading video"));
     QNetworkRequest request;
     request.setUrl(QUrl(url));
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1");
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(parseJoggsVideoPage()));
 
@@ -435,7 +424,6 @@ void UrlGrabber::getYouJizzVideoUrl(const QString &url) {
     emit busy(tr("Loading video"));
     QNetworkRequest request;
     request.setUrl(QUrl(url));
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1");
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(parseYouJizzVideoPage()));
 
@@ -466,16 +454,18 @@ void UrlGrabber::parseYouJizzVideoPage() {
 }
 
 void UrlGrabber::getRampantTVVideoUrl(const QString &url) {
-    emit busy(tr("Loading video"));
-    QNetworkRequest request;
-    request.setUrl(QUrl(url));
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1");
-    QNetworkReply *reply = networkAccessManager()->get(request);
-    connect(reply, SIGNAL(finished()), this, SLOT(parseRampantTVVideoPage()));
+    emit gotVideoUrl(url.section('/', 0, -2).replace("thumbs", "videos"));
 
-    if (m_mode == UrlGrabber::PlaybackMode) {
-        connect(reply, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(updateProgress(qint64,qint64)));
-    }
+//    emit busy(tr("Loading video"));
+//    QNetworkRequest request;
+//    request.setUrl(QUrl(url));
+//    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1");
+//    QNetworkReply *reply = networkAccessManager()->get(request);
+//    connect(reply, SIGNAL(finished()), this, SLOT(parseRampantTVVideoPage()));
+
+//    if (m_mode == UrlGrabber::PlaybackMode) {
+//        connect(reply, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(updateProgress(qint64,qint64)));
+//    }
 }
 
 void UrlGrabber::parseRampantTVVideoPage() {
@@ -501,7 +491,6 @@ void UrlGrabber::parseRampantTVVideoPage() {
 
 void UrlGrabber::getRampantTVVideoParams(const QUrl &url) {
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:7.0.1) Gecko/20100101 Firefox/7.0.1");
     QNetworkReply *reply = networkAccessManager()->get(request);
     connect(reply, SIGNAL(finished()), this, SLOT(parseRampantTVVideoParams()));
 }
