@@ -26,6 +26,9 @@ private slots:
     void onLoadingChanged();
     void addVideoDownloads();
     void addAudioDownloads();
+    void showContextMenu(const QPoint &pos);
+    void addVideoDownload();
+    void addAudioDownload();
     void onItemClicked(const QModelIndex &index);
 
 private:
@@ -33,6 +36,9 @@ private:
     XTubeVideoListModel *m_model;
     QAction *m_videoDownloadAction;
     QAction *m_audioDownloadAction;
+    QMenu *m_contextMenu;
+    QAction *m_videoDownloadContextAction;
+    QAction *m_audioDownloadContextAction;
     QLabel *m_noResultsLabel;
 };
 
