@@ -129,7 +129,7 @@ void YouTubeRelatedVideosTab::queueVideos() {
 }
 
 void YouTubeRelatedVideosTab::showContextMenu(const QPoint &pos) {
-    m_contextMenu->popup(pos, m_addToFavouritesAction);
+    m_contextMenu->popup(pos, m_addToFavouritesContextAction);
 }
 
 void YouTubeRelatedVideosTab::addVideoToFavourites() {
