@@ -161,7 +161,7 @@ void YouTubeVideoListTab::queueVideos() {
 }
 
 void YouTubeVideoListTab::showContextMenu(const QPoint &pos) {
-    m_contextMenu->popup(pos, m_deleteFromUploadsAction);
+    m_contextMenu->popup(pos, m_deleteFromUploadsContextAction);
 }
 
 void YouTubeVideoListTab::deleteVideoFromUploads() {
