@@ -137,7 +137,7 @@ void YouTubeVideoListWindow::queueVideos() {
 }
 
 void YouTubeVideoListWindow::showContextMenu(const QPoint &pos) {
-    m_contextMenu->popup(pos, m_deleteFromUploadsAction);
+    m_contextMenu->popup(pos, m_deleteFromUploadsContextAction);
 }
 
 void YouTubeVideoListWindow::deleteVideoFromUploads() {
